@@ -393,7 +393,7 @@ def HHV(serial,index,period):
     rtn = serial[indx][2]
     for i in range(index-1,index-period-1,-1):
         if rtn < serial[i][2]:
-            rtn = serial[i][2]:
+            rtn = serial[i][2]
     return rtn
 
 def LLV(serial,index,period):
